@@ -1,20 +1,6 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* SPDX-License-Identifier: LGPL-2.1-or-later */
 /*
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301 USA.
- *
  * Copyright (C) 2014-2021 Aleksander Morgado <aleksander@aleksander.es>
  */
 
@@ -245,6 +231,40 @@ gboolean mbim_message_ms_basic_connect_extensions_lte_attach_status_notification
     MbimDeprecatedLteAttachStatus **out_lte_attach_status,
     GError **error);
 
+/*****************************************************************************/
+/* Network errors fixup */
+
+/* The following type exists just so that we can get deprecation warnings */
+G_DEPRECATED
+typedef int MbimDeprecatedNwError;
+
+/**
+ * MBIM_NW_ERROR_UNKNOWN:
+ *
+ * Network error not set.
+ *
+ * Since: 1.0
+ * Deprecated: 1.28: Use %MBIM_NW_ERROR_NONE instead.
+ */
+#define MBIM_NW_ERROR_UNKNOWN (MbimDeprecatedNwError) MBIM_NW_ERROR_NONE
+
+/*****************************************************************************/
+/* Rename blacklist to denylist */
+
+/* The following type exists just so that we can get deprecation warnings */
+G_DEPRECATED
+typedef int MbimDeprecatedCidMsBasicConnectExtensions;
+
+/**
+ * MBIM_CID_MS_BASIC_CONNECT_EXTENSIONS_NETWORK_BLACKLIST:
+ *
+ * Network deny list.
+ *
+ * Since: 1.18
+ * Deprecated: 1.28: Use MBIM_CID_MS_BASIC_CONNECT_EXTENSIONS_NETWORK_DENYLIST instead.
+ */
+#define MBIM_CID_MS_BASIC_CONNECT_EXTENSIONS_NETWORK_BLACKLIST (MbimDeprecatedCidMsBasicConnectExtensions) MBIM_CID_MS_BASIC_CONNECT_EXTENSIONS_NETWORK_DENYLIST
+
 #endif /* MBIM_DISABLE_DEPRECATED */
 
 G_END_DECLS
