@@ -1,20 +1,8 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* SPDX-License-Identifier: GPL-2.0-or-later */
 /*
  * mbimcli -- Command line interface to control MBIM devices
  *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
  * Copyright 2018 Google LLC
  */
 
@@ -31,21 +19,28 @@
 #include <libmbim-glib.h>
 
 #include "mbimcli.h"
+#include "mbimcli-helpers.h"
 
 /* Context */
 typedef struct {
-    MbimDevice *device;
+    MbimDevice   *device;
     GCancellable *cancellable;
 } Context;
 static Context *ctx;
 
 /* Options */
-static gboolean modem_reboot_flag;
+static gboolean  modem_reboot_set;
+static gchar    *modem_reboot_str;
+
+static gboolean modem_reboot_arg_parse (const gchar  *option_name,
+                                        const gchar  *value,
+                                        gpointer      user_data,
+                                        GError      **error);
 
 static GOptionEntry entries[] = {
-    { "intel-modem-reboot", 0, 0, G_OPTION_ARG_NONE, &modem_reboot_flag,
-      "Reboot modem",
-      NULL
+    { "intel-modem-reboot", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK, G_CALLBACK (modem_reboot_arg_parse),
+      "Reboot modem. Boot mode and timeout arguments only required if MBIMEx >= 2.0.",
+      "[(Boot Mode),(Timeout)]"
     },
     { NULL }
 };
@@ -65,16 +60,27 @@ mbimcli_intel_firmware_update_get_option_group (void)
    return group;
 }
 
+static gboolean
+modem_reboot_arg_parse (const gchar  *option_name,
+                        const gchar  *value,
+                        gpointer      user_data,
+                        GError      **error)
+{
+    modem_reboot_set = TRUE;
+    modem_reboot_str = g_strdup (value);
+    return TRUE;
+}
+
 gboolean
 mbimcli_intel_firmware_update_options_enabled (void)
 {
-    static guint n_actions = 0;
+    static guint    n_actions = 0;
     static gboolean checked = FALSE;
 
     if (checked)
         return !!n_actions;
 
-    n_actions = modem_reboot_flag;
+    n_actions = modem_reboot_set;
 
     if (n_actions > 1) {
         g_printerr ("error: too many Intel Firmware Update Service actions requested\n");
@@ -126,11 +132,44 @@ modem_reboot_ready (MbimDevice   *device,
     shutdown (TRUE);
 }
 
+static gboolean
+modem_reboot_v2_input_parse (const gchar       *str,
+                             MbimIntelBootMode *out_boot_mode,
+                             guint32           *out_timeout)
+{
+    g_auto(GStrv) split = NULL;
+
+    split = g_strsplit (modem_reboot_str, ",", -1);
+
+    if (g_strv_length (split) > 2) {
+        g_printerr ("error: couldn't parse input string, too many arguments\n");
+        return FALSE;
+    }
+
+    if (g_strv_length (split) < 2) {
+        g_printerr ("error: couldn't parse input string, missing arguments\n");
+        return FALSE;
+    }
+
+    if (!mbimcli_read_intel_boot_mode_from_string (split[0], out_boot_mode)) {
+        g_printerr ("error: couldn't read boot mode, wrong value given as input\n");
+        return FALSE;
+    }
+
+    if (!mbimcli_read_uint_from_string (split[1], out_timeout)) {
+        g_printerr ("error: couldn't read timeout value\n");
+        return FALSE;
+    }
+
+    return TRUE;
+}
+
 void
 mbimcli_intel_firmware_update_run (MbimDevice   *device,
                                    GCancellable *cancellable)
 {
     g_autoptr(MbimMessage) request = NULL;
+    g_autoptr(GError)      error = NULL;
 
     /* Initialize context */
     ctx = g_slice_new (Context);
@@ -138,9 +177,30 @@ mbimcli_intel_firmware_update_run (MbimDevice   *device,
     ctx->cancellable = cancellable ? g_object_ref (cancellable) : NULL;
 
     /* Request to reboot modem? */
-    if (modem_reboot_flag) {
-        g_debug ("Asynchronously rebooting modem...");
-        request = (mbim_message_intel_firmware_update_modem_reboot_set_new (NULL));
+    if (modem_reboot_set) {
+        if (mbim_device_check_ms_mbimex_version (device, 2, 0)) {
+            MbimIntelBootMode  boot_mode = MBIM_INTEL_BOOT_MODE_NORMAL_MODE;
+            guint32            timeout = 0;
+
+            if (!modem_reboot_v2_input_parse (modem_reboot_str, &boot_mode, &timeout)) {
+                g_printerr ("error: couldn't parse input arguments\n");
+                g_printerr ("error: device in MBIMEx >= 2.0 requires boot mode and timeout arguments.\n");
+                shutdown (FALSE);
+                return;
+            }
+
+            request = mbim_message_intel_firmware_update_v2_modem_reboot_set_new (boot_mode, timeout, NULL);
+        } else {
+            if (modem_reboot_str) {
+                g_printerr ("error: arguments are not expected in MBIMEx < 2.0\n");
+                shutdown (FALSE);
+                return;
+            }
+
+            g_debug ("Asynchronously rebooting modem...");
+            request = mbim_message_intel_firmware_update_modem_reboot_set_new (NULL);
+        }
+
         mbim_device_command (ctx->device,
                              request,
                              10,
