@@ -1,20 +1,8 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* SPDX-License-Identifier: GPL-2.0-or-later */
 /*
  * mbimcli -- Command line interface to control MBIM devices
  *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
  * Copyright (C) 2013 - 2014 Aleksander Morgado <aleksander@aleksander.es>
  */
 
@@ -49,10 +37,13 @@ static gboolean operation_status;
 /* Main options */
 static gchar *device_str;
 static gboolean device_open_proxy_flag;
+static gboolean device_open_ms_mbimex_v2_flag;
+static gboolean device_open_ms_mbimex_v3_flag;
 static gchar *no_open_str;
 static gboolean no_close_flag;
 static gboolean noop_flag;
 static gboolean verbose_flag;
+static gboolean verbose_full_flag;
 static gboolean silent_flag;
 static gboolean version_flag;
 
@@ -65,6 +56,14 @@ static GOptionEntry main_entries[] = {
       "Request to use the 'mbim-proxy' proxy",
       NULL
     },
+    { "device-open-ms-mbimex-v2", 0, 0, G_OPTION_ARG_NONE, &device_open_ms_mbimex_v2_flag,
+      "Request to enable Microsoft MBIMEx v2.0 support",
+      NULL
+    },
+    { "device-open-ms-mbimex-v3", 0, 0, G_OPTION_ARG_NONE, &device_open_ms_mbimex_v3_flag,
+      "Request to enable Microsoft MBIMEx v3.0 support",
+      NULL
+    },
     { "no-open", 0, 0, G_OPTION_ARG_STRING, &no_open_str,
       "Do not explicitly open the MBIM device before running the command",
       "[Transaction ID]"
@@ -81,6 +80,10 @@ static GOptionEntry main_entries[] = {
       "Run action with verbose logs, including the debug ones",
       NULL
     },
+    { "verbose-full", 0, 0, G_OPTION_ARG_NONE, &verbose_full_flag,
+      "Run action with verbose logs, including the debug ones and personal info",
+      NULL
+    },
     { "silent", 0, 0, G_OPTION_ARG_NONE, &silent_flag,
       "Run action with no logs; not even the error/warning ones",
       NULL
@@ -163,7 +166,7 @@ log_handler (const gchar *log_domain,
         g_assert_not_reached ();
     }
 
-    if (!verbose_flag && !err)
+    if (!verbose_flag && !verbose_full_flag && !err)
         return;
 
     g_fprintf (err ? stderr : stdout,
@@ -299,6 +302,15 @@ device_open_ready (MbimDevice   *dev,
     case MBIM_SERVICE_QUECTEL:
         mbimcli_quectel_run (dev, cancellable);
         return;
+    case MBIM_SERVICE_INTEL_THERMAL_RF:
+        mbimcli_intel_thermal_rf_run (dev, cancellable);
+        return;
+    case MBIM_SERVICE_MS_VOICE_EXTENSIONS:
+        mbimcli_ms_voice_extensions_run (dev, cancellable);
+        return;
+    case MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS:
+        mbimcli_ms_uicc_low_level_access_run (dev, cancellable);
+        return;
     case MBIM_SERVICE_SMS:
     case MBIM_SERVICE_USSD:
     case MBIM_SERVICE_STK:
@@ -306,7 +318,6 @@ device_open_ready (MbimDevice   *dev,
     case MBIM_SERVICE_PROXY_CONTROL:
     case MBIM_SERVICE_QMI:
     case MBIM_SERVICE_QDU:
-    case MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS:
         /* unsupported actions in the CLI */
     case MBIM_SERVICE_INVALID:
     default:
@@ -347,6 +358,10 @@ device_new_ready (GObject      *unused,
     /* Setup device open flags */
     if (device_open_proxy_flag)
         open_flags |= MBIM_DEVICE_OPEN_FLAGS_PROXY;
+    if (device_open_ms_mbimex_v2_flag)
+        open_flags |= MBIM_DEVICE_OPEN_FLAGS_MS_MBIMEX_V2;
+    if (device_open_ms_mbimex_v3_flag)
+        open_flags |= MBIM_DEVICE_OPEN_FLAGS_MS_MBIMEX_V3;
 
     /* Open the device */
     mbim_device_open_full (device,
@@ -417,6 +432,21 @@ parse_actions (void)
         actions_enabled++;
     }
 
+    if (mbimcli_intel_thermal_rf_options_enabled ()) {
+        service = MBIM_SERVICE_INTEL_THERMAL_RF;
+        actions_enabled++;
+    }
+
+    if (mbimcli_ms_voice_extensions_options_enabled ()) {
+        service = MBIM_SERVICE_MS_VOICE_EXTENSIONS;
+        actions_enabled++;
+    }
+
+    if (mbimcli_ms_uicc_low_level_access_options_enabled ()) {
+        service = MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS;
+        actions_enabled++;
+    }
+
     /* Noop */
     if (noop_flag)
         actions_enabled++;
@@ -433,6 +463,11 @@ parse_actions (void)
         exit (EXIT_FAILURE);
     }
 
+    if (device_open_ms_mbimex_v2_flag && device_open_ms_mbimex_v3_flag) {
+        g_printerr ("error: cannot request both MBIMEx v2.0 and 3.0 at the same time\n");
+        exit (EXIT_FAILURE);
+    }
+
     /* Go on! */
 }
 
@@ -457,6 +492,9 @@ int main (int argc, char **argv)
     g_option_context_add_group (context, mbimcli_ms_basic_connect_extensions_get_option_group ());
     g_option_context_add_group (context, mbimcli_quectel_get_option_group ());
     g_option_context_add_group (context, mbimcli_link_management_get_option_group ());
+    g_option_context_add_group (context, mbimcli_intel_thermal_rf_get_option_group ());
+    g_option_context_add_group (context, mbimcli_ms_voice_extensions_get_option_group ());
+    g_option_context_add_group (context, mbimcli_ms_uicc_low_level_access_get_option_group ());
     g_option_context_add_main_entries (context, main_entries, NULL);
     if (!g_option_context_parse (context, &argc, &argv, &error)) {
         g_printerr ("error: %s\n", error->message);
@@ -468,8 +506,17 @@ int main (int argc, char **argv)
 
     g_log_set_handler (NULL, G_LOG_LEVEL_MASK, log_handler, NULL);
     g_log_set_handler ("Mbim", G_LOG_LEVEL_MASK, log_handler, NULL);
-    if (verbose_flag)
+
+    if (verbose_flag && verbose_full_flag) {
+        g_printerr ("error: cannot specify --verbose and --verbose-full at the same time\n");
+        exit (EXIT_FAILURE);
+    } else if (verbose_flag) {
         mbim_utils_set_traces_enabled (TRUE);
+        mbim_utils_set_show_personal_info (FALSE);
+    } else if (verbose_full_flag) {
+        mbim_utils_set_traces_enabled (TRUE);
+        mbim_utils_set_show_personal_info (TRUE);
+    }
 
     /* No device path given? */
     if (!device_str) {
